check_expr

Function check_expr 

fn check_expr(ctx: &LintContext<'_, '_>, expr: &Expr<'_>, allow_bare: bool)
Reports boolean literals in expr that are not allow_bare at the top level: a literal stored, returned or passed as an argument is fine, one combined into a larger expression or used as a condition is a misuse.